==> apache-reef-0.11.0-incubating.tar.gz: apache-reef-0.11.0-incubating/lang/java/reef-wake/wake/src/main/java/org/apache/reef/wake/impl/WakeUncaughtExceptionHandler.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.reef.wake.impl;

import org.apache.reef.wake.EventHandler;

/**
 * Exception handler for uncaught exceptions
 */
public final class WakeUncaughtExceptionHandler implements Thread.UncaughtExceptionHandler {
  private EventHandler<Throwable> errorHandler;

  public WakeUncaughtExceptionHandler() {
  }

  public WakeUncaughtExceptionHandler(final EventHandler<Throwable> errorHandler) {
    this.errorHandler = errorHandler;
  }

  public void setErrorHandler(EventHandler<Throwable> errorHandler) {
    this.errorHandler = errorHandler;
  }

  @Override
  public void uncaughtException(Thread t, Throwable e) {
    final String msg = "Thread " + t.getName() + " threw an uncaught exception.";
    if (errorHandler != null)
      errorHandler.onNext(new Exception(msg, e));
  }
}

==> apache-reef-0.12.0-incubating.tar.gz: apache-reef-0.12.0-incubating/lang/java/reef-wake/wake/src/main/java/org/apache/reef/wake/impl/WakeUncaughtExceptionHandler.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.reef.wake.impl;

import org.apache.reef.wake.EventHandler;

/**
 * Exception handler for uncaught exceptions.
 */
public final class WakeUncaughtExceptionHandler implements Thread.UncaughtExceptionHandler {
  private EventHandler<Throwable> errorHandler;

  public WakeUncaughtExceptionHandler() {
  }

  public WakeUncaughtExceptionHandler(final EventHandler<Throwable> errorHandler) {
    this.errorHandler = errorHandler;
  }

  public void setErrorHandler(final EventHandler<Throwable> errorHandler) {
    this.errorHandler = errorHandler;
  }

  @Override
  public void uncaughtException(final Thread t, final Throwable e) {
    final String msg = "Thread " + t.getName() + " threw an uncaught exception.";
    if (errorHandler != null) {
      errorHandler.onNext(new Exception(msg, e));
    }
  }
}
